from django.shortcuts import get_object_or_404, render 
from django.urls.base import reverse, reverse_lazy
from django.views.generic import ListView, CreateView, DetailView, DeleteView
from django.views.generic import UpdateView


from webapp.models import Course
from webapp.forms import CourseForm


class CourseCreateView(CreateView):
    template_name = 'courses/create.html'
    form_class = CourseForm
    model = Course 
    pk_url_kwarg = 'project_pk'

    def get_form(self, form_class=None):
        form = super().get_form()
        return form


class CoursesListView(ListView):
    model = Course
    context_object_name = 'courses'
    template_name = 'courses/courses_list.html'
    paginate_by = 9


class CourseDetailView(DetailView):
    model = Course 
    template_name = 'courses/detail.html'
    pk_url_kwarg = 'course_pk'


class CourseDeleteView(DeleteView): 
    model = Course 
    template_name = 'courses/delete.html'
    success_url = reverse_lazy('courses_list')


class CourseEditView(UpdateView):
    model = Course
    fields = ['title', 'description', 'start_date']
    template_name = 'courses/edit.html'

